package com.supervision;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.io.FileUtil;
import cn.hutool.json.JSONUtil;
import com.supervision.qanything.QanythingService;
import com.supervision.qanything.dto.ChatResult;
import com.supervision.qanything.dto.CreateKBResult;
import com.supervision.qanything.dto.ResultWrapper;
import com.supervision.qanything.dto.UploadResult;
import lombok.extern.slf4j.Slf4j;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

import java.io.File;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

@Slf4j
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
@RunWith(SpringJUnit4ClassRunner.class)
public class YoudaoTest {



    @Autowired
    private QanythingService qanythingService;


    @Test
    public void qanythingChatTest() throws NoSuchAlgorithmException {

       /* ResultWrapper<ChatResult> chat = qanythingService.chat("怎样创建创建知识库", CollUtil.newArrayList("KB249d43fdb96f4e1399340b8f95e1baa0_240328"));

        System.out.println("返回结果:"+ JSONUtil.toJsonStr(chat));
        System.out.println(chat.getResult().getResponse());*/
    }

    @Test
    public void qanythingUploadDocTest() throws NoSuchAlgorithmException {

        //
        ResultWrapper<List<UploadResult>> resultWrapper = qanythingService.fileList("KB403a6543629648a3a74b60be5707398f_240328");
        List<UploadResult> result = resultWrapper.getResult();
        Set<String> fileNames = result.stream().map(UploadResult::getFileName).collect(Collectors.toSet());

        FileUtil.walkFiles(new File("F:\\supervision\\doc\\深圳人社\\养老退休文档"),(f)->{
            if (fileNames.contains(f.getName()) || f.getName().contains(".mp4")){
                return;
            }
            try {
                qanythingService.uploadDoc("KB403a6543629648a3a74b60be5707398f_240328",f);
            } catch (NoSuchAlgorithmException e) {
                throw new RuntimeException(e);
            }
        });
    }

    @Test
    public void qanythingKbListTest() throws NoSuchAlgorithmException {

        ResultWrapper<List<CreateKBResult>> listResultWrapper = qanythingService.kbList();
        // {"errorCode":"0","msg":"SUCCESS","requestId":"a7281218-17eb-44dc-9817-d5deb812c16b","result":[{"kbId":"KB249d43fdb96f4e1399340b8f95e1baa0_240328","kbName":"测试知识库"}]}

        System.out.println(listResultWrapper.getResult());
    }

    @Test
    public void qanythingFileListTest() throws NoSuchAlgorithmException {

        ResultWrapper<List<UploadResult>> resultWrapper = qanythingService.fileList("KB249d43fdb96f4e1399340b8f95e1baa0_240328");

        // {"errorCode":"0","msg":"SUCCESS","requestId":"5f651ab1-43ca-4d04-af05-794cf55e4a5d","result":[{"fileId":"7c1af28235284934aabb1daeb16f4383","fileName":"qanthing.md","status":"1","url":"https://ai-virtual-person.nos-jd.163yun.com/6baa3e021848020ec8afc699decba96c?Signature=oUJTnEH6ZNl8QYiYRqkGj%2F9PeTGUzpxFJD%2FfTVm%2B2vs%3D&Expires=1714311144&NOSAccessKeyId=22d00336bf1e47b2a159c4ad33b9b762&download=qanthing.md"},{"fileId":"09eab2d3de084c3babbad7cf913c37a6","fileName":"aaa.md","status":"1","url":"https://ai-virtual-person.nos-jd.163yun.com/62dc3fb272e75eb9d0d659a0ff12845c?Signature=o6yPXcUu0xxWCkRXX32KGSXeVFKE02Ti5gKgBn2cVgM%3D&Expires=1714402794&NOSAccessKeyId=22d00336bf1e47b2a159c4ad33b9b762&download=aaa.md"}]}
        System.out.println(resultWrapper.getResult());
    }


    @Test
    public void qanythingUploadUrlTest() throws NoSuchAlgorithmException {

        ResultWrapper<List<UploadResult>> resultWrapper = qanythingService.uploadUrl("KB249d43fdb96f4e1399340b8f95e1baa0_240328","https://blog.csdn.net/zxj20041003/article/details/137551140");

        // {"errorCode":"0","msg":"SUCCESS","requestId":"30665c3a-ecc9-44d6-8f85-dc7f38bf3753","result":{"fileId":"96ea740652394b3a991ca336f4a678b2","fileName":"https://blog.csdn.net/kangli_zhang/article/details/131209634","status":"0"}}
        System.out.println(resultWrapper.getResult());
    }

    @Test
    public void qanythingDeleteFileTest() throws NoSuchAlgorithmException {

        ResultWrapper<List<String>> resultWrapper = qanythingService.deleteFile("KB249d43fdb96f4e1399340b8f95e1baa0_240328", CollUtil.newArrayList("96ea740652394b3a991ca336f4a678b2"));

        // {"errorCode":"0","msg":"SUCCESS","requestId":"3ec1278d-7d55-463d-89a4-89123f8d1e77","result":null}
        System.out.println(resultWrapper.getResult());
    }


    @Test
    public void qanythingCreateKBTest() throws NoSuchAlgorithmException {

        ResultWrapper<CreateKBResult> resultWrapper = qanythingService.createKB("养老退休知识库");

        // {"errorCode":"0","msg":"SUCCESS","requestId":"a9ff5740-e644-4c8a-b6d8-64959de7a135","result":{"kbId":"KB32ac03789c464cba878a390e566b053b_240328","kbName":"测试库2"}}
        System.out.println(resultWrapper.getResult());
    }
    //deleteKB

    @Test
    public void qanythingDeleteKBTest() throws NoSuchAlgorithmException {

        ResultWrapper<String> resultWrapper = qanythingService.deleteKB("KB32ac03789c464cba878a390e566b053b_240328");

        // {"errorCode":"0","msg":"SUCCESS","requestId":"6d1c37a6-f10f-438a-a372-57ab6aeabba0","result":null}
        System.out.println(resultWrapper.getResult());
    }
}
